package org.ovirt.engine.ui.webadmin.section.main.view.popup.host.panels;

import com.google.gwt.resources.client.CssResource;

public interface NetworkPanelsStyle extends CssResource {
    String actionButtonNetwork();

    String actionButtonBond();

    String bondPanel();

    String emptyPanel();

    String groupPanel();

    String unassignedNetworksPanel();

    String itemPanel();

    String mgmtNetwork();

    String networkGroupDragOver();

    String networkImageBorder();

    String networkPanel();

    String nicPanel();

    String statusLabel();

    String checkCon();

    String commitChanges();

    String requiredTitlePanel();

    String requiredLabel();
}
